[−][src]Function atomic_lib::client::post_commit
pub fn post_commit(commit: &Commit) -> AtomicResult<()>
Posts a Commit to the endpoint of the Subject from the Commit
pub fn post_commit(commit: &Commit) -> AtomicResult<()>
Posts a Commit to the endpoint of the Subject from the Commit