CommitBuilder

Struct CommitBuilder 

pub struct CommitBuilder { /* private fields */ }
Use this for creating Commits.

Implementations

Source

impl CommitBuilder

pub fn new(subject: String) -> Self

Start constructing a Commit.

pub fn push_propval( &mut self, property: &str, value: SubResource, ) -> AtomicResult<()>

Appends a URL or (nested anonymous) Resource to a ResourceArray.

pub fn sign( self, agent: &Agent, store: &impl Storelike, resource: &Resource, ) -> AtomicResult<Commit>

Creates the Commit and signs it using a signature. Does not send it - see [atomic_lib::client::post_commit]. Private key is the base64 encoded pkcs8 for the signer. Sets the previousCommit using the lastCommit.

pub fn set(&mut self, prop: String, val: Value)

Set Property / Value combinations that will either be created or overwritten.

pub fn set_subject(&mut self, subject: String)

Set a new subject for this Commit

pub fn remove(&mut self, prop: String)

Set Property URLs which values to be removed

pub fn destroy(&mut self, destroy: bool)

Whether the resource needs to be removed fully