Module atomic_lib::errors [−][src]
The Error type that you can expect when using this library
Type Definitions
The default Error type for all Atomic Lib Errors.
The Error type that you can expect when using this library
The default Error type for all Atomic Lib Errors.