pub enum Right {
Read,
Write,
Append,
}Variants
Read
Full read access to the resource and its children. urls::READ
Write
Full edit, update, destroy access to the resource and its children. urls::WRITE
Append
Create new children (append to tree) urls::APPEND