[][src]Module atomic_lib::parse

Parsing / deserialization / decoding

Constants

AD3_MIME

Functions

parse_ad3

Parses an Atomic Data Triples (.ad3) string and adds the Atoms to the store. Allows comments and empty lines.

parse_json_ad_map_to_propvals

Parse a single Json AD string, convert to Atoms Does not match all props to datatypes, so it could result in invalid data.

parse_json_ad_resource

Parse a single Json AD string, convert to Atoms Does not match all props to datatypes (in Nested Resources), so it could result in invalid data.

parse_json_array