Store

Struct Store 

pub struct Store {
    pub base_domain: Arc<Mutex<Option<String>>>,
    /* private fields */
}
The in-memory store of data, containing the Resources, Properties and Classes It uses the default_agent as the default client.

Fields

base_domain: Arc<Mutex<Option<String>>>

The base domain of the store

Implementations

Source

impl Store

pub async fn init() -> AtomicResult<Store>

Creates an empty Store. Run .populate() to get useful standard models loaded into your store.

pub fn set_base_url(&self, url: &str)

Sets the base URL of the store.