[−][src]Module atomic_lib::values
A value is the part of an Atom that contains the actual information.
Structs
| UnsupportedValue | When the Datatype of a Value is not handled by this library |
Enums
| Value | An individual Value in an Atom, represented as a native Rust enum. |
Constants
| DATE_REGEX | YYYY-MM-DD |
| SLUG_REGEX | Only alphanumeric characters, no spaces |