pub struct CommitBuilder { /* private fields */ }Expand description
Use this for creating Commits.
Implementations
Sourceimpl CommitBuilder
impl CommitBuilder
Sourcepub fn push_propval(
&mut self,
property: &str,
value: SubResource,
) -> AtomicResult<()>
pub fn push_propval( &mut self, property: &str, value: SubResource, ) -> AtomicResult<()>
Appends a URL or (nested anonymous) Resource to a ResourceArray.
Sourcepub fn sign(
self,
agent: &Agent,
store: &impl Storelike,
resource: &Resource,
) -> AtomicResult<Commit>
pub fn sign( self, agent: &Agent, store: &impl Storelike, resource: &Resource, ) -> AtomicResult<Commit>
Creates the Commit and signs it using a signature.
Does not send it - see [atomic_lib::client::post_commit].
Private key is the base64 encoded pkcs8 for the signer.
Sets the previousCommit using the lastCommit.
Sourcepub fn set(&mut self, prop: String, val: Value)
pub fn set(&mut self, prop: String, val: Value)
Set Property / Value combinations that will either be created or overwritten.
Sourcepub fn set_subject(&mut self, subject: String)
pub fn set_subject(&mut self, subject: String)
Set a new subject for this Commit