Struct atomic_lib::store::Store [−][src]
pub struct Store { /* fields omitted */ }Expand description
The in-memory store of data, containing the Resources, Properties and Classes
Implementations
Creates an empty Store.
Run .populate() to get useful standard models loaded into your store.