[−][src]Struct atomic_lib::store::Store
The in-memory store of data, containing the Resources, Properties and Classes
Implementations
impl Store[src]
pub fn init() -> AtomicResult<Store>[src]
Creates an empty Store.
Run .populate() to get useful standard models loaded into your store.
pub fn read_store_from_file(&self, path: &PathBuf) -> AtomicResult<()>[src]
Reads an .ad3 (Atomic Data Triples) graph and adds it to the store
pub fn write_store_to_disk(&self, path: &PathBuf) -> AtomicResult<()>[src]
Serializes the current store and saves to path